#
# spec file for package tuner
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.louis77.tuner
Name:           tuner
Version:        1.5.5
Release:        1.1
Summary:        Minimalist radio station player
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/louis77/tuner
Source:         %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         fix-gschema.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.44
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-player-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-3.0)
Recommends:     gstreamer-plugins-base
Recommends:     gstreamer-plugins-good
Recommends:     gstreamer-plugins-libav
Recommends:     gstreamer-plugins-ugly

%description
An Internet Radio Station player for the Pantheon Desktop.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/*/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Mon Nov 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.5.5:
  * Updated HTTP Session params to improve response
  * Increased Search re-fire interval to reduce number of concurrent searches
  * Made Search asynchronous so UI remains responsive during searches
  * Ignore request to load failing favicons URLs
  * Removed shadow from.svg images per Flathub quality directives
  * Removed org.gnome.SettingsDaemon.MediaKeys from manifest per flathub
- update to 1.5.4:
  * Added API server lookup via SRV and backup via JSON, plus randomization
  * Added JSON validation for empty nodes
  * Refactored libsoup calls out to HttpClient.vala
  * Refactored loading of favicons to Favicon.vala
  * Turned off TLS checks for HTTP calls to avoid non loading of favicons with
    invalid certs
- update to 1.5.3:
  * Upgrade taglib to v1.13.1
  * Documentation correction.
- add patch fix-gschema.patch, for fixing glib-schemas-compile
- update spec file for Leap 16.0:
  * remove %%suse_update_desktop_file
  * remove recommending lang package
  * remove mentions of elementary
  * use autosetup
  * remove HiDPI workaround
* Thu Oct 31 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused pkgconfig(geocode-glib-1.0) and
  pkgconfig(libgeoclue-2.0) BuildRequires.
* Sun Sep  1 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 1.5.2:
  Tuner is back! After more than 2 years of pause, development of Tuner started again.
  In this first maintenance release, the following issues have been fixed:
  * Upgrade to libsoup-3.0
  * Fix issues with endpoints not working
  * Removed geo location services (they never really worked)
  * Increase default size of Window
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.1:
  * Update taglib 1.11 to 1.12
  * Change pause button to stop button, fixes #79
  * Update copyright headers
  * Update monetization info for AppCenter
  * Remove debian packaging files
  * Update Copyright year
  * Add GitHub CI
* Sat Nov 20 2021 Alexei Podvalsky <avvissu@yandex.by>
- Add gstreamer-plugins-libav as recommended dependencies
* Fri Nov  5 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.0:
  * Make station list flexible (1-3 columns)
  * Update version number
  * Add release info to appdata
  * Merge branch 'master' of github.com:louis77/tuner
  * Implement background playback #67
  * Merge pull request #70 from Henryws/master
  * Remove sudo and update pacstall URL
  * Replace theme switch with 3-mode dropdown
  * Move Preferences in separate class
  * Merge pull request #65 from SwampRabbit/master
  * Update README.md
  * Merge pull request #64 from ryonakano/ryonakano/setup-l10n
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.4:
  * l10n: Correctly setup the locales
  * Remove multiple default screenshots, fixes #62
  * Update screenshots, prepare for 1.4.2 release
  * Remove debug noise
  * Merge branch 'master' of github.com:louis77/tuner
  * Merge pull request #61 from krisives/granite-dark-mode
  * Added support for reacting to dark mode changing outside of
    the app.
  * Remove FSF membership badge
  * Change email address (no more FSF)
  * Add Stripe key to appdata for new eOS 6, fixes #58
  * Merge pull request #59 from krisives/flatpak
  * Fixed Flatpak manifest to use current directory.
  * Added Flatpak manifest.
  * Merge pull request #55 from Vistaus/master
  * Use join_paths instead of / for older meson version
  * Prepare for release 1.4.0
  * Implement Auto-play and Window title
  * Persist last volume in gsettings
  * Add libera.chat channel
  * Update README, looking for contributors
  * Fix dark-mode not persisted in gsettings #47
  * Add volume control #43
  * Add codec and bitrate to station box #48
  * Relicense source files under GPL3
  * Localize Country display in StationBox
  * Merge pull request #51 from albanobattistella/patch-2
  * Merge pull request #50 from albanobattistella/patch-1
  * Create FUNDING.yml
  * Update it.po
  * Merge pull request #46 from kousu/configurable-api
  * Update RadioBrowserDirectory.vala
  * Document new environment variable
  * Take API server via an environment variable
  * ...
* Sun Oct 11 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.0:
  * Show current track if station supports it
  * Add dutch translation, thanks to @Vistaus
* Thu Aug 27 2020 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
